:Emphasis:`a`

:Literal:`a`

:code:`a`

:math:`a b\  c..:x`

:pep-reference:`2`

:rfc-reference:`2`

:pep:`2`

:rfc:`2`

:strong:`a`

:subscript:`a\ b`

:superscript:`a`

:title-reference:`a`

``a``

``a \ b``

:literal:`a\` \ b`

:math:`a\`\ b`

**a\*b**

*\*a\*b*

**a \*b**

*\*a b c\*b*
